# coding: utf-8

"""
    VeeRoute.LSS Account

    LSS Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.4.161082
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.date_statistics import DateStatistics  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestDateStatistics(unittest.TestCase):
    """DateStatistics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DateStatistics
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.date_statistics.DateStatistics()  # noqa: E501
        if include_optional :
            return DateStatistics(
                date = 'Mon Oct 05 03:00:00 MSK 2020', 
                services = [
                    vrt_lss_account.models.service_statistics.ServiceStatistics(
                        service = 'Lastmile', 
                        methods = [
                            vrt_lss_account.models.method_statistics.MethodStatistics(
                                method = 'plan', 
                                unique_points_per_day = 1500, 
                                points_per_day = 1500, )
                            ], )
                    ]
            )
        else :
            return DateStatistics(
                date = 'Mon Oct 05 03:00:00 MSK 2020',
                services = [
                    vrt_lss_account.models.service_statistics.ServiceStatistics(
                        service = 'Lastmile', 
                        methods = [
                            vrt_lss_account.models.method_statistics.MethodStatistics(
                                method = 'plan', 
                                unique_points_per_day = 1500, 
                                points_per_day = 1500, )
                            ], )
                    ],
        )

    def testDateStatistics(self):
        """Test DateStatistics"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
